@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,18 +20,17 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.translate_v3beta1.services.translation_service import pagers
 from google.cloud.translate_v3beta1.types import translation_service
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import TranslationServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TranslationServiceGrpcAsyncIOTransport
 from .client import TranslationServiceClient
@@ -49,31 +46,26 @@ class TranslationServiceAsyncClient:
 
     glossary_path = staticmethod(TranslationServiceClient.glossary_path)
     parse_glossary_path = staticmethod(TranslationServiceClient.parse_glossary_path)
-
     common_billing_account_path = staticmethod(
         TranslationServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         TranslationServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(TranslationServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         TranslationServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         TranslationServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         TranslationServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(TranslationServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         TranslationServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(TranslationServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         TranslationServiceClient.parse_common_location_path
@@ -81,7 +73,8 @@ class TranslationServiceAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -96,7 +89,7 @@ class TranslationServiceAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -113,7 +106,7 @@ class TranslationServiceAsyncClient:
 
     @property
     def transport(self) -> TranslationServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             TranslationServiceTransport: The transport used by the client instance.
@@ -128,12 +121,12 @@ class TranslationServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, TranslationServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the translation service client.
+        """Instantiates the translation service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -165,7 +158,6 @@ class TranslationServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = TranslationServiceClient(
             credentials=credentials,
             transport=transport,
@@ -187,7 +179,6 @@ class TranslationServiceAsyncClient:
             request (:class:`google.cloud.translate_v3beta1.types.TranslateTextRequest`):
                 The request object. The request message for synchronous
                 translation.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -199,7 +190,6 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = translation_service.TranslateTextRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -282,7 +272,6 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``mime_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -309,7 +298,6 @@ class TranslationServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if model is not None:
@@ -404,7 +392,6 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -431,7 +418,6 @@ class TranslationServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if display_language_code is not None:
@@ -448,7 +434,8 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -481,7 +468,6 @@ class TranslationServiceAsyncClient:
         Args:
             request (:class:`google.cloud.translate_v3beta1.types.TranslateDocumentRequest`):
                 The request object. A document translation request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -495,7 +481,6 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = translation_service.TranslateDocumentRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -539,7 +524,6 @@ class TranslationServiceAsyncClient:
         Args:
             request (:class:`google.cloud.translate_v3beta1.types.BatchTranslateTextRequest`):
                 The request object. The batch translation request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -557,7 +541,6 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = translation_service.BatchTranslateTextRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -609,7 +592,6 @@ class TranslationServiceAsyncClient:
         Args:
             request (:class:`google.cloud.translate_v3beta1.types.BatchTranslateDocumentRequest`):
                 The request object. The BatchTranslateDocument request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -627,7 +609,6 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = translation_service.BatchTranslateDocumentRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -684,7 +665,6 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``glossary`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -714,7 +694,6 @@ class TranslationServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if glossary is not None:
@@ -806,7 +785,6 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -835,7 +813,6 @@ class TranslationServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if filter is not None:
@@ -850,7 +827,8 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -898,7 +876,6 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -925,7 +902,6 @@ class TranslationServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -938,7 +914,8 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -981,7 +958,6 @@ class TranslationServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1011,7 +987,6 @@ class TranslationServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -1024,7 +999,8 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
